==> lxqt-panel-2.2.1.tar.xz: lxqt-panel-2.2.1/plugin-mainmenu/translations/mainmenu_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="108"/>
        <source>Search...</source>
        <translation>検索...</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="118"/>
        <source>Show/hide main menu</source>
        <translation>アプリケーションメニューの表示/非表示</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="467"/>
        <source>Add to desktop</source>
        <translation>デスクトップに追加する</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="475"/>
        <source>Question</source>
        <translation>質問</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="476"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation>同じ名前のファイルが既に存在します。
上書きしますか？</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="482"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="483"/>
        <source>The file cannot be overwritten.</source>
        <translation>ファイルを上書き出来ません。</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="489"/>
        <source>Copy</source>
        <translation>コピー</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>全般</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu Settings</source>
        <translation>アプリケーションメニューの設定</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="26"/>
        <source>Icon:</source>
        <translation>アイコン:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="50"/>
        <source>Button text:</source>
        <translation>ボタンの文字列:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="67"/>
        <source>Custom font size:</source>
        <translation>フォントサイズの指定:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="77"/>
        <source> pt</source>
        <translation> ポイント</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="96"/>
        <source>Menu file</source>
        <translation>メニューファイル</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="102"/>
        <source>Menu file:</source>
        <translation>メニューファイル:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="147"/>
        <source>Search</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="181"/>
        <source>Max. item width:</source>
        <translation>アイテムの表示最大幅:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="160"/>
        <source>Show matching entries:</source>
        <translation>一致するエントリ名を表示する:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="167"/>
        <source>Maximum visible items:</source>
        <translation>アイテムの表示最大数:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="153"/>
        <source>Filter menu entries</source>
        <translation>メニューエントリを絞り込む</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="188"/>
        <source> px</source>
        <translation> ピクセル</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="201"/>
        <source>Hide menu entries while searching</source>
        <translation>検索中はメニューエントリを隠す</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="208"/>
        <source>Clear search upon showing menu</source>
        <translation>メニューを表示した時、検索フォームをクリアする</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="118"/>
        <source>Keyboard Shortcut</source>
        <translation>ショートカットキー</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="124"/>
        <source>Click the button to record shortcut:</source>
        <translation>ショートカットを記録するには次のボタンをクリック:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="76"/>
        <source>Reset</source>
        <translation>リセット</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="176"/>
        <source>Choose icon file</source>
        <translation>アイコンファイルの選択</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="178"/>
        <source>Images (*.svg *.png)</source>
        <translation>画像 (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="190"/>
        <source>Choose menu file</source>
        <translation>メニューファイルの選択</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="192"/>
        <source>Menu files (*.menu)</source>
        <translation>メニューファイル (*.menu)</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.3.2.tar.xz: lxqt-panel-2.3.2/plugin-mainmenu/translations/mainmenu_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="108"/>
        <source>Search...</source>
        <translation>検索...</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="118"/>
        <source>Show/hide main menu</source>
        <translation>アプリケーションメニューの表示/非表示</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="469"/>
        <source>Add to desktop</source>
        <translation>デスクトップに追加</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="477"/>
        <source>Question</source>
        <translation>質問</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="478"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation>同じ名前のファイルが既に存在します。
上書きしますか？</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="484"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="485"/>
        <source>The file cannot be overwritten.</source>
        <translation>ファイルを上書き出来ません。</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="491"/>
        <source>Copy</source>
        <translation>コピー</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>全般</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu Settings</source>
        <translation>アプリケーションメニューの設定</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="26"/>
        <source>Icon:</source>
        <translation>アイコン:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="50"/>
        <source>Button text:</source>
        <translation>ボタンの文字列:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="67"/>
        <source>Custom font size:</source>
        <translation>フォントサイズの指定:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="77"/>
        <source> pt</source>
        <translation> ポイント</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="96"/>
        <source>Menu file</source>
        <translation>メニューファイル</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="102"/>
        <source>Menu file:</source>
        <translation>メニューファイル:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="147"/>
        <source>Search</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="181"/>
        <source>Max. item width:</source>
        <translation>アイテムの表示最大幅:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="160"/>
        <source>Show matching entries:</source>
        <translation>一致するエントリ名を表示する:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="167"/>
        <source>Maximum visible items:</source>
        <translation>アイテムの表示最大数:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="153"/>
        <source>Filter menu entries</source>
        <translation>メニューエントリを絞り込む</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="188"/>
        <source> px</source>
        <translation> ピクセル</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="201"/>
        <source>Hide menu entries while searching</source>
        <translation>検索中はメニューエントリを隠す</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="208"/>
        <source>Clear search upon showing menu</source>
        <translation>メニューを表示した時、検索フォームをクリアする</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="118"/>
        <source>Keyboard Shortcut</source>
        <translation>ショートカットキー</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="124"/>
        <source>Click the button to record shortcut:</source>
        <translation>ショートカットを登録するにはボタンをクリックします:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="76"/>
        <source>Reset</source>
        <translation>リセット</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="177"/>
        <source>Choose icon file</source>
        <translation>アイコンファイルの選択</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="179"/>
        <source>Images (*.svg *.png)</source>
        <translation>画像 (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="191"/>
        <source>Choose menu file</source>
        <translation>メニューファイルの選択</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="193"/>
        <source>Menu files (*.menu)</source>
        <translation>メニューファイル (*.menu)</translation>
    </message>
</context>
</TS>
